parse_spectrum_text

Function parse_spectrum_text 

pub fn parse_spectrum_text(text: &str) -> Result<Vec<f64>, IoError>
Parse spectrum values from a string.

Extracts the first numeric column. Lines starting with # are comments. The first non-comment line that cannot be parsed as a number is treated as a header and skipped (only one such line is allowed).